"""
    ExplainaBoard

    Backend APIs for ExplainaBoard  # noqa: E501

    The version of the OpenAPI document: 0.2.2
    Contact: explainaboard@gmail.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from explainaboard_api_client.api_client import ApiClient, Endpoint as _Endpoint
from explainaboard_api_client.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from explainaboard_api_client.model.api_error import APIError
from explainaboard_api_client.model.analysis_cases_return import AnalysisCasesReturn
from explainaboard_api_client.model.benchmark import Benchmark
from explainaboard_api_client.model.benchmark_config import BenchmarkConfig
from explainaboard_api_client.model.dataset_metadata import DatasetMetadata
from explainaboard_api_client.model.datasets_return import DatasetsReturn
from explainaboard_api_client.model.inline_object import InlineObject
from explainaboard_api_client.model.inline_response200 import InlineResponse200
from explainaboard_api_client.model.system import System
from explainaboard_api_client.model.system_analyses_return import SystemAnalysesReturn
from explainaboard_api_client.model.system_create_props import SystemCreateProps
from explainaboard_api_client.model.system_outputs_return import SystemOutputsReturn
from explainaboard_api_client.model.systems_return import SystemsReturn
from explainaboard_api_client.model.task_category import TaskCategory
from explainaboard_api_client.model.user import User


class DefaultApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.benchmark_configs_get_endpoint = _Endpoint(
            settings={
                'response_type': ([BenchmarkConfig],),
                'auth': [],
                'endpoint_path': '/benchmarkconfigs',
                'operation_id': 'benchmark_configs_get',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'parent_id',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'parent_id':
                        (str,),
                },
                'attribute_map': {
                    'parent_id': 'parent_id',
                },
                'location_map': {
                    'parent_id': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.benchmark_get_by_id_endpoint = _Endpoint(
            settings={
                'response_type': (Benchmark,),
                'auth': [],
                'endpoint_path': '/benchmark/{benchmark_id}',
                'operation_id': 'benchmark_get_by_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'benchmark_id',
                    'by_creator',
                ],
                'required': [
                    'benchmark_id',
                    'by_creator',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'benchmark_id':
                        (str,),
                    'by_creator':
                        (bool,),
                },
                'attribute_map': {
                    'benchmark_id': 'benchmark_id',
                    'by_creator': 'by_creator',
                },
                'location_map': {
                    'benchmark_id': 'path',
                    'by_creator': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.datasets_get_endpoint = _Endpoint(
            settings={
                'response_type': (DatasetsReturn,),
                'auth': [],
                'endpoint_path': '/datasets',
                'operation_id': 'datasets_get',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'dataset_ids',
                    'dataset_name',
                    'task',
                    'page',
                    'page_size',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                    'page',
                    'page_size',
                ]
            },
            root_map={
                'validations': {
                    ('page',): {

                        'inclusive_minimum': 0,
                    },
                    ('page_size',): {

                        'inclusive_minimum': 0,
                    },
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'dataset_ids':
                        (str,),
                    'dataset_name':
                        (str,),
                    'task':
                        (str,),
                    'page':
                        (int,),
                    'page_size':
                        (int,),
                },
                'attribute_map': {
                    'dataset_ids': 'dataset_ids',
                    'dataset_name': 'dataset_name',
                    'task': 'task',
                    'page': 'page',
                    'page_size': 'page_size',
                },
                'location_map': {
                    'dataset_ids': 'query',
                    'dataset_name': 'query',
                    'task': 'query',
                    'page': 'query',
                    'page_size': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.datasets_get_by_id_endpoint = _Endpoint(
            settings={
                'response_type': (DatasetMetadata,),
                'auth': [],
                'endpoint_path': '/datasets/{dataset_id}',
                'operation_id': 'datasets_get_by_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'dataset_id',
                ],
                'required': [
                    'dataset_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'dataset_id':
                        (str,),
                },
                'attribute_map': {
                    'dataset_id': 'dataset_id',
                },
                'location_map': {
                    'dataset_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.info_get_endpoint = _Endpoint(
            settings={
                'response_type': (InlineResponse200,),
                'auth': [],
                'endpoint_path': '/info',
                'operation_id': 'info_get',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.system_cases_get_by_id_endpoint = _Endpoint(
            settings={
                'response_type': (AnalysisCasesReturn,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/systems/{system_id}/cases',
                'operation_id': 'system_cases_get_by_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'system_id',
                    'level',
                    'case_ids',
                ],
                'required': [
                    'system_id',
                    'level',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'system_id':
                        (str,),
                    'level':
                        (str,),
                    'case_ids':
                        (str,),
                },
                'attribute_map': {
                    'system_id': 'system_id',
                    'level': 'level',
                    'case_ids': 'case_ids',
                },
                'location_map': {
                    'system_id': 'path',
                    'level': 'query',
                    'case_ids': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.system_outputs_get_by_id_endpoint = _Endpoint(
            settings={
                'response_type': (SystemOutputsReturn,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/systems/{system_id}/outputs',
                'operation_id': 'system_outputs_get_by_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'system_id',
                    'output_ids',
                ],
                'required': [
                    'system_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'system_id':
                        (str,),
                    'output_ids':
                        (str,),
                },
                'attribute_map': {
                    'system_id': 'system_id',
                    'output_ids': 'output_ids',
                },
                'location_map': {
                    'system_id': 'path',
                    'output_ids': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.systems_analyses_post_endpoint = _Endpoint(
            settings={
                'response_type': (SystemAnalysesReturn,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/systems/analyses',
                'operation_id': 'systems_analyses_post',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'inline_object',
                ],
                'required': [
                    'inline_object',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'inline_object':
                        (InlineObject,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'inline_object': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.systems_delete_by_id_endpoint = _Endpoint(
            settings={
                'response_type': (str,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/systems/{system_id}',
                'operation_id': 'systems_delete_by_id',
                'http_method': 'DELETE',
                'servers': None,
            },
            params_map={
                'all': [
                    'system_id',
                ],
                'required': [
                    'system_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'system_id':
                        (str,),
                },
                'attribute_map': {
                    'system_id': 'system_id',
                },
                'location_map': {
                    'system_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.systems_get_endpoint = _Endpoint(
            settings={
                'response_type': (SystemsReturn,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/systems',
                'operation_id': 'systems_get',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'system_name',
                    'task',
                    'dataset',
                    'subdataset',
                    'split',
                    'page',
                    'page_size',
                    'sort_field',
                    'sort_direction',
                    'creator',
                    'shared_users',
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                    'sort_direction',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('sort_direction',): {

                        "ASC": "asc",
                        "DESC": "desc"
                    },
                },
                'openapi_types': {
                    'system_name':
                        (str,),
                    'task':
                        (str,),
                    'dataset':
                        (str,),
                    'subdataset':
                        (str,),
                    'split':
                        (str,),
                    'page':
                        (int,),
                    'page_size':
                        (int,),
                    'sort_field':
                        (str,),
                    'sort_direction':
                        (str,),
                    'creator':
                        (str,),
                    'shared_users':
                        ([str],),
                },
                'attribute_map': {
                    'system_name': 'system_name',
                    'task': 'task',
                    'dataset': 'dataset',
                    'subdataset': 'subdataset',
                    'split': 'split',
                    'page': 'page',
                    'page_size': 'page_size',
                    'sort_field': 'sort_field',
                    'sort_direction': 'sort_direction',
                    'creator': 'creator',
                    'shared_users': 'shared_users',
                },
                'location_map': {
                    'system_name': 'query',
                    'task': 'query',
                    'dataset': 'query',
                    'subdataset': 'query',
                    'split': 'query',
                    'page': 'query',
                    'page_size': 'query',
                    'sort_field': 'query',
                    'sort_direction': 'query',
                    'creator': 'query',
                    'shared_users': 'query',
                },
                'collection_format_map': {
                    'shared_users': 'multi',
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.systems_get_by_id_endpoint = _Endpoint(
            settings={
                'response_type': (System,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/systems/{system_id}',
                'operation_id': 'systems_get_by_id',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'system_id',
                ],
                'required': [
                    'system_id',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'system_id':
                        (str,),
                },
                'attribute_map': {
                    'system_id': 'system_id',
                },
                'location_map': {
                    'system_id': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.systems_post_endpoint = _Endpoint(
            settings={
                'response_type': (System,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/systems',
                'operation_id': 'systems_post',
                'http_method': 'POST',
                'servers': None,
            },
            params_map={
                'all': [
                    'system_create_props',
                ],
                'required': [
                    'system_create_props',
                ],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                    'system_create_props':
                        (SystemCreateProps,),
                },
                'attribute_map': {
                },
                'location_map': {
                    'system_create_props': 'body',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [
                    'application/json'
                ]
            },
            api_client=api_client
        )
        self.tasks_get_endpoint = _Endpoint(
            settings={
                'response_type': ([TaskCategory],),
                'auth': [],
                'endpoint_path': '/tasks',
                'operation_id': 'tasks_get',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.user_get_endpoint = _Endpoint(
            settings={
                'response_type': (User,),
                'auth': [
                    'ApiKeyAuth',
                    'BearerAuth'
                ],
                'endpoint_path': '/user',
                'operation_id': 'user_get',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                ],
                'required': [],
                'nullable': [
                ],
                'enum': [
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                },
                'openapi_types': {
                },
                'attribute_map': {
                },
                'location_map': {
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def benchmark_configs_get(
        self,
        **kwargs
    ):
        """Returns all benchmark configs matching the specification  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.benchmark_configs_get(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            parent_id (str): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            [BenchmarkConfig]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.benchmark_configs_get_endpoint.call_with_http_info(**kwargs)

    def benchmark_get_by_id(
        self,
        benchmark_id: str,
        by_creator: bool,
        **kwargs
    ):
        """Returns benchmark metadata by id  # noqa: E501

        Returns benchmark metadata by id.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.benchmark_get_by_id(benchmark_id, by_creator, async_req=True)
        >>> result = thread.get()

        Args:
            benchmark_id (str):
            by_creator (bool):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Benchmark
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['benchmark_id'] = \
            benchmark_id
        kwargs['by_creator'] = \
            by_creator
        return self.benchmark_get_by_id_endpoint.call_with_http_info(**kwargs)

    def datasets_get(
        self,
        **kwargs
    ):
        """Returns a list of datasets  # noqa: E501

        Returns a list of datasets. Returns empty list if current page is empty. Returns `total=0` if no match datasets.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.datasets_get(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            dataset_ids (str): a string of comma separated dataset ids.. [optional]
            dataset_name (str): fuzzy match for dataset name. [optional]
            task (str): filter by task type. [optional]
            page (int): page number (0 indexed). [optional] if omitted the server will use the default value of 0
            page_size (int): number of items per page. [optional] if omitted the server will use the default value of 20
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            DatasetsReturn
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.datasets_get_endpoint.call_with_http_info(**kwargs)

    def datasets_get_by_id(
        self,
        dataset_id: str,
        **kwargs
    ):
        """Returns dataset metadata by id  # noqa: E501

        Returns dataset metadata by id. id is the DB id so it is mostly used internally. See datasets MGet endpoints for general use.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.datasets_get_by_id(dataset_id, async_req=True)
        >>> result = thread.get()

        Args:
            dataset_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            DatasetMetadata
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['dataset_id'] = \
            dataset_id
        return self.datasets_get_by_id_endpoint.call_with_http_info(**kwargs)

    def info_get(
        self,
        **kwargs
    ):
        """information for environment identifier, backend version, login URL, etc. (not intent for public users)  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.info_get(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            InlineResponse200
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.info_get_endpoint.call_with_http_info(**kwargs)

    def system_cases_get_by_id(
        self,
        system_id: str,
        level: str,
        **kwargs
    ):
        """Returns a list of analysis cases of a particular system.  # noqa: E501

        This will fail if the user doesn't have permissions for that system.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.system_cases_get_by_id(system_id, level, async_req=True)
        >>> result = thread.get()

        Args:
            system_id (str): system id
            level (str): analysis level

        Keyword Args:
            case_ids (str): multiple output_ids, comma-separated. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            AnalysisCasesReturn
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['system_id'] = \
            system_id
        kwargs['level'] = \
            level
        return self.system_cases_get_by_id_endpoint.call_with_http_info(**kwargs)

    def system_outputs_get_by_id(
        self,
        system_id: str,
        **kwargs
    ):
        """Returns a list of outputs of a particular system.  # noqa: E501

        This will fail if the user doesn't have permissions for that system.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.system_outputs_get_by_id(system_id, async_req=True)
        >>> result = thread.get()

        Args:
            system_id (str): system id

        Keyword Args:
            output_ids (str): multiple output_ids, comma-separated. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            SystemOutputsReturn
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['system_id'] = \
            system_id
        return self.system_outputs_get_by_id_endpoint.call_with_http_info(**kwargs)

    def systems_analyses_post(
        self,
        inline_object: InlineObject,
        **kwargs
    ):
        """Returns analysis result(s) of one or multiple systems  # noqa: E501

        Returns analysis result(s) of one or multiple systems  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.systems_analyses_post(inline_object, async_req=True)
        >>> result = thread.get()

        Args:
            inline_object (InlineObject):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            SystemAnalysesReturn
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['inline_object'] = \
            inline_object
        return self.systems_analyses_post_endpoint.call_with_http_info(**kwargs)

    def systems_delete_by_id(
        self,
        system_id: str,
        **kwargs
    ):
        """Deletes a system by id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.systems_delete_by_id(system_id, async_req=True)
        >>> result = thread.get()

        Args:
            system_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            str
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['system_id'] = \
            system_id
        return self.systems_delete_by_id_endpoint.call_with_http_info(**kwargs)

    def systems_get(
        self,
        **kwargs
    ):
        """Returns a list of systems  # noqa: E501

        only public systems are returned for unauthenticated requests  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.systems_get(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            system_name (str): fuzzy match for system name. [optional]
            task (str): filter by task type. [optional]
            dataset (str): dataset name. [optional]
            subdataset (str): subdataset name. [optional]
            split (str): dataset split. [optional]
            page (int): page number (0 indexed). [optional] if omitted the server will use the default value of 0
            page_size (int): number of items per page. [optional] if omitted the server will use the default value of 20
            sort_field (str): supports `created_at` (default) and metric names.. [optional]
            sort_direction (str): [optional]
            creator (str): [optional]
            shared_users ([str]): [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            SystemsReturn
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.systems_get_endpoint.call_with_http_info(**kwargs)

    def systems_get_by_id(
        self,
        system_id: str,
        **kwargs
    ):
        """Returns system metadata info by id  # noqa: E501

        Returns a system_metadata by id. id is the DB id so it is mostly used internally.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.systems_get_by_id(system_id, async_req=True)
        >>> result = thread.get()

        Args:
            system_id (str):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            System
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['system_id'] = \
            system_id
        return self.systems_get_by_id_endpoint.call_with_http_info(**kwargs)

    def systems_post(
        self,
        system_create_props: SystemCreateProps,
        **kwargs
    ):
        """Submits a system  # noqa: E501

        Submits a system  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.systems_post(system_create_props, async_req=True)
        >>> result = thread.get()

        Args:
            system_create_props (SystemCreateProps):

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            System
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['system_create_props'] = \
            system_create_props
        return self.systems_post_endpoint.call_with_http_info(**kwargs)

    def tasks_get(
        self,
        **kwargs
    ):
        """Returns all task categories and tasks  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.tasks_get(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            [TaskCategory]
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.tasks_get_endpoint.call_with_http_info(**kwargs)

    def user_get(
        self,
        **kwargs
    ):
        """get user info  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.user_get(async_req=True)
        >>> result = thread.get()


        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _spec_property_naming (bool): True if the variable names in the input data
                are serialized names, as specified in the OpenAPI document.
                False if the variable names in the input data
                are pythonic names, e.g. snake case (default)
            _content_type (str/None): force body content-type.
                Default is None and content-type will be predicted by allowed
                content-types and body.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            User
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_spec_property_naming'] = kwargs.get(
            '_spec_property_naming', False
        )
        kwargs['_content_type'] = kwargs.get(
            '_content_type')
        kwargs['_host_index'] = kwargs.get('_host_index')
        return self.user_get_endpoint.call_with_http_info(**kwargs)




# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from explainaboard_api_client.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from explainaboard_api_client.model.api_error import APIError
from explainaboard_api_client.model.analysis import Analysis
from explainaboard_api_client.model.analysis_case import AnalysisCase
from explainaboard_api_client.model.analysis_cases_return import AnalysisCasesReturn
from explainaboard_api_client.model.analysis_level import AnalysisLevel
from explainaboard_api_client.model.analysis_result import AnalysisResult
from explainaboard_api_client.model.any_type import AnyType
from explainaboard_api_client.model.benchmark import Benchmark
from explainaboard_api_client.model.benchmark_config import BenchmarkConfig
from explainaboard_api_client.model.benchmark_dataset_config import BenchmarkDatasetConfig
from explainaboard_api_client.model.benchmark_metric import BenchmarkMetric
from explainaboard_api_client.model.benchmark_operation_config import BenchmarkOperationConfig
from explainaboard_api_client.model.benchmark_table_data import BenchmarkTableData
from explainaboard_api_client.model.benchmark_view_config import BenchmarkViewConfig
from explainaboard_api_client.model.bucket_performance import BucketPerformance
from explainaboard_api_client.model.class_label import ClassLabel
from explainaboard_api_client.model.dataset_feature import DatasetFeature
from explainaboard_api_client.model.dataset_metadata import DatasetMetadata
from explainaboard_api_client.model.datasets_return import DatasetsReturn
from explainaboard_api_client.model.feature_type import FeatureType
from explainaboard_api_client.model.inline_object import InlineObject
from explainaboard_api_client.model.inline_response200 import InlineResponse200
from explainaboard_api_client.model.metric_config import MetricConfig
from explainaboard_api_client.model.paper import Paper
from explainaboard_api_client.model.performance import Performance
from explainaboard_api_client.model.significance_test_info import SignificanceTestInfo
from explainaboard_api_client.model.single_analysis import SingleAnalysis
from explainaboard_api_client.model.system import System
from explainaboard_api_client.model.system_all_of import SystemAllOf
from explainaboard_api_client.model.system_all_of_dataset import SystemAllOfDataset
from explainaboard_api_client.model.system_analyses_return import SystemAnalysesReturn
from explainaboard_api_client.model.system_create_props import SystemCreateProps
from explainaboard_api_client.model.system_info import SystemInfo
from explainaboard_api_client.model.system_info_results import SystemInfoResults
from explainaboard_api_client.model.system_metadata import SystemMetadata
from explainaboard_api_client.model.system_output import SystemOutput
from explainaboard_api_client.model.system_output_props import SystemOutputProps
from explainaboard_api_client.model.system_outputs_return import SystemOutputsReturn
from explainaboard_api_client.model.systems_analyses_feature_to_bucket_info import SystemsAnalysesFeatureToBucketInfo
from explainaboard_api_client.model.systems_return import SystemsReturn
from explainaboard_api_client.model.task import Task
from explainaboard_api_client.model.task_category import TaskCategory
from explainaboard_api_client.model.task_metadata import TaskMetadata
from explainaboard_api_client.model.task_supported_formats import TaskSupportedFormats
from explainaboard_api_client.model.time import Time
from explainaboard_api_client.model.tokenizer import Tokenizer
from explainaboard_api_client.model.user import User
from explainaboard_api_client.model.value import Value



"""
    ExplainaBoard

    Backend APIs for ExplainaBoard  # noqa: E501

    The version of the OpenAPI document: 0.2.2
    Contact: explainaboard@gmail.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import explainaboard_api_client
from explainaboard_api_client.model.benchmark_dataset_config import BenchmarkDatasetConfig
from explainaboard_api_client.model.benchmark_metric import BenchmarkMetric
from explainaboard_api_client.model.benchmark_view_config import BenchmarkViewConfig
from explainaboard_api_client.model.paper import Paper
globals()['BenchmarkDatasetConfig'] = BenchmarkDatasetConfig
globals()['BenchmarkMetric'] = BenchmarkMetric
globals()['BenchmarkViewConfig'] = BenchmarkViewConfig
globals()['Paper'] = Paper
from explainaboard_api_client.model.benchmark_config import BenchmarkConfig


class TestBenchmarkConfig(unittest.TestCase):
    """BenchmarkConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testBenchmarkConfig(self):
        """Test BenchmarkConfig"""
        # FIXME: construct object with mandatory attributes with example values
        # model = BenchmarkConfig()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



"""
    ExplainaBoard

    Backend APIs for ExplainaBoard  # noqa: E501

    The version of the OpenAPI document: 0.2.2
    Contact: explainaboard@gmail.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import explainaboard_api_client
from explainaboard_api_client.api.default_api import DefaultApi  # noqa: E501


class TestDefaultApi(unittest.TestCase):
    """DefaultApi unit test stubs"""

    def setUp(self):
        self.api = DefaultApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_benchmark_configs_get(self):
        """Test case for benchmark_configs_get

        Returns all benchmark configs matching the specification  # noqa: E501
        """
        pass

    def test_benchmark_get_by_id(self):
        """Test case for benchmark_get_by_id

        Returns benchmark metadata by id  # noqa: E501
        """
        pass

    def test_datasets_get(self):
        """Test case for datasets_get

        Returns a list of datasets  # noqa: E501
        """
        pass

    def test_datasets_get_by_id(self):
        """Test case for datasets_get_by_id

        Returns dataset metadata by id  # noqa: E501
        """
        pass

    def test_info_get(self):
        """Test case for info_get

        information for environment identifier, backend version, login URL, etc. (not intent for public users)  # noqa: E501
        """
        pass

    def test_system_cases_get_by_id(self):
        """Test case for system_cases_get_by_id

        Returns a list of analysis cases of a particular system.  # noqa: E501
        """
        pass

    def test_system_outputs_get_by_id(self):
        """Test case for system_outputs_get_by_id

        Returns a list of outputs of a particular system.  # noqa: E501
        """
        pass

    def test_systems_analyses_post(self):
        """Test case for systems_analyses_post

        Returns analysis result(s) of one or multiple systems  # noqa: E501
        """
        pass

    def test_systems_delete_by_id(self):
        """Test case for systems_delete_by_id

        Deletes a system by id  # noqa: E501
        """
        pass

    def test_systems_get(self):
        """Test case for systems_get

        Returns a list of systems  # noqa: E501
        """
        pass

    def test_systems_get_by_id(self):
        """Test case for systems_get_by_id

        Returns system metadata info by id  # noqa: E501
        """
        pass

    def test_systems_post(self):
        """Test case for systems_post

        Submits a system  # noqa: E501
        """
        pass

    def test_tasks_get(self):
        """Test case for tasks_get

        Returns all task categories and tasks  # noqa: E501
        """
        pass

    def test_user_get(self):
        """Test case for user_get

        get user info  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

"""
    ExplainaBoard

    Backend APIs for ExplainaBoard  # noqa: E501

    The version of the OpenAPI document: 0.2.2
    Contact: explainaboard@gmail.com
    Generated by: https://openapi-generator.tech
"""


__version__ = "0.2.2"

# import ApiClient
from explainaboard_api_client.api_client import ApiClient

# import Configuration
from explainaboard_api_client.configuration import Configuration

# import exceptions
from explainaboard_api_client.exceptions import OpenApiException
from explainaboard_api_client.exceptions import ApiAttributeError
from explainaboard_api_client.exceptions import ApiTypeError
from explainaboard_api_client.exceptions import ApiValueError
from explainaboard_api_client.exceptions import ApiKeyError
from explainaboard_api_client.exceptions import ApiException



"""
    ExplainaBoard

    Backend APIs for ExplainaBoard  # noqa: E501

    The version of the OpenAPI document: 0.2.2
    Contact: explainaboard@gmail.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import explainaboard_api_client
from explainaboard_api_client.model.system_all_of import SystemAllOf
from explainaboard_api_client.model.system_all_of_dataset import SystemAllOfDataset
from explainaboard_api_client.model.system_info import SystemInfo
from explainaboard_api_client.model.time import Time
globals()['SystemAllOf'] = SystemAllOf
globals()['SystemAllOfDataset'] = SystemAllOfDataset
globals()['SystemInfo'] = SystemInfo
globals()['Time'] = Time
from explainaboard_api_client.model.system import System


class TestSystem(unittest.TestCase):
    """System unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testSystem(self):
        """Test System"""
        # FIXME: construct object with mandatory attributes with example values
        # model = System()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
